@@ -67,7 +67,7 @@ sppregs<-function(samp,env,tree=NULL,fam="gaussian"){
 
   } else {
   
-    if (!require(brglm)) {
+    if (!requireNamespace("brglm")) {
         stop("The 'brglm' package is required to use this function with argument fam=binomial.")
     }
 
@@ -75,7 +75,7 @@ sppregs<-function(samp,env,tree=NULL,fam="gaussian"){
     for(i in 1:nspp)
     {
       y<-samp[,i]
-      mod<-brglm(formu,data=data.frame(cbind(y,env)))
+      mod<-brglm::brglm(formu,data=data.frame(cbind(y,env)))
       spp.resids<-cbind(spp.resids,mod$y-mod$fitted.values)
       spp.fits<-cbind(spp.fits,mod$fitted.values)
       spp.coef<-cbind(spp.coef,summary(mod)$coef[,1])
@@ -134,4 +134,4 @@ sppregs.plot<-function(sppreg,rows=c(1,3),cex.mag=1,x.label="phylogenetic correl
   abline(0,0,lty=2)
   plot(sppreg$cors.phylo,sppreg$cors.resid-sppreg$cors.pa,xlab=x.label,ylab=y.label[3],main=paste("cor =",round(cor(sppreg$cors.phylo,sppreg$cors.resid-sppreg$cors.pa,use="pairwise.complete.obs"),4)))
   abline(0,0,lty=2)
-}
\ No newline at end of file
+}
